package com.java4less.rchart.samples;

import java.io.IOException;
import java.io.InputStream;

import com.java4less.rchart.Chart;
import com.java4less.rchart.ChartAdapter;
import com.java4less.rchart.ChartListener;
import com.java4less.rchart.ChartAdapter;
import com.java4less.rchart.ChartListener;
import com.java4less.rchart.ChartLoader;
import com.java4less.rchart.android.ChartPanel;
import com.java4less.rchart.gc.android.ChartAndroidImage;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;

public class ShowChart extends Activity {
	
	private static final String TAG = "j4lchart";
	ChartLoader cha=new ChartLoader();
	ChartPanel chartPanel;
	

	// create chart listener 
	ChartAdapter chartAdapter=new ChartAdapter() {
					public void chartEvent(Chart c,int type) {
						
						Log.e(ChartPanel.TAG,"Chart event "+ type);
						
						if (type==ChartListener.EVENT_CHART_CLICKED) {
							
						}
						
						if (type==ChartListener.EVENT_POINT_CLICKED) {
							Log.e(ChartPanel.TAG,"Point clicked "+ c.selectedSeriePoint);
						}						

						// rebuild chart with new data
						if (type==ChartListener.EVENT_BEFORE_UPDATE) {
							// // get a new random value between 0 and 40 and update 3 of the values in the serie
							int newValue=(int) (System.currentTimeMillis() % 40); 
							c.plotters[0].getSerie(0).replaceYValueAt(1,newValue);
							c.plotters[0].getSerie(0).replaceYValueAt(2,newValue+10);
							c.plotters[0].getSerie(0).replaceYValueAt(3,newValue-10);							

							// do not allow the chart to be rebuilt from the original parameters
							c.autoRebuild=false;
							
						}						
						
					}
				};	
					
				
				// create chart listener for the drill down chart
				ChartAdapter chartAdapterRealtime=new ChartAdapter() {
									public void chartEvent(Chart c,int type) {
										Log.e(ChartPanel.TAG,"Chart event "+ type);						
										// load subchart
										if (type==ChartListener.EVENT_BEFORE_UPDATE) createRealtimedata(cha);
									}
								};	

	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle icicle) {
    	 cha=new ChartLoader();
    		// this is to be able to load the images
    	    ChartAndroidImage.assets=getAssets();
    	    
    	    String chartfile=this.getIntent().getStringExtra("com.java4less.rchart.samples.file");
	        super.onCreate(icicle);

	        //setContentView(R.layout.main);
	        chartPanel = new ChartPanel(this);

	        try {
				chartPanel.setChart(loadFromAsset(chartfile));
	        	//chartPanel.setChart(this.createDefaultChart());
			} catch (Exception e) {
				Log.e(ChartPanel.TAG,"Could not lod chart from file.",e);
			}
	        
	        setContentView(chartPanel);        
	    }
    
    	protected void onDestroy() {
    		
    		if (chartPanel!=null) 
    				if (chartPanel.getChart()!=null) chartPanel.getChart().stopUpdater();
    		
    		super.onDestroy();
    	}	
 
	    
        /**
         * load chart definition from file
         * @param name
         * @return
         */  
        public Chart loadFromAsset(String name) throws IOException {
        	
            InputStream is = getAssets().open(name);        	
            	
            cha.loadFromFile(is, true);
            
			Log.i(ChartPanel.TAG,"Building chart ...");

			Chart c=cha.build(false,false);	
			c.setWidth(300);
			c.setHeight(300);
			
			// scroll example
			if (name.equals("linechart.txt"))  {
			c.virtualWidth=600;
			c.withScroll=true;
			c.repaintAlways=false;			
			}
			

			// set listener for realtime update example
			//if (name.equals("barChart3D.txt")) 
				c.addChartListener(chartAdapter);				
			if (name.equals("realtime.txt")) c.addChartListener(chartAdapterRealtime);
						

			
						
			
			// real time update example, start update thread
			if ((name.equals("barChart3D.txt")) || (name.equals("realtime.txt")))  c.startUpdater();				
			
			Log.i(ChartPanel.TAG,"Build ok");	
			
			c.activateSelection=true;
			
			return c;            
        }
    
	    public Chart createDefaultChart() {

			System.out.println("Creating loader ...");

			ChartLoader cha=new ChartLoader();			
			cha.clearParams();	
		
			
			int[]  values=new int[] {20,30,40,40,60,70};
			int ymax=140;
			
			cha.setParameter("YSCALE_MAX",""+ymax);
			cha.setParameter("YSCALE_MIN","0");
			cha.setParameter("XSCALE_MIN","0");
			cha.setParameter("XSCALE_MAX","7");
			cha.setParameter("BIG_TICK_INTERVALY","1");
			cha.setParameter("TICK_INTERVALY","10");
			
			String s="";
			for (int i=0;i<values.length;i++) {
				if (s.length()>0) s=s+"|";
				s=s+(ymax-20-values[i]);
			}
			
			cha.setParameter("SERIE_DATA_1",s);		
			
			s="";
			for (int i=0;i<values.length;i++) {
				if (s.length()>0) s=s+"|";
				s=s+(values[i]);
			}			
			
			cha.setParameter("SERIE_DATA_LABELS_1",s);
			
			cha.setParameter("YAXIS_LABELS","dB|110|100|90|80|70|60|50|40|30|20|10|0|-10");
			
			cha.setParameter("BIG_TICK_INTERVALX","1");
			cha.setParameter("TICK_INTERVALX","1");
			
			cha.setParameter("SERIE_DATAX_1","1|2|3|4|5|6|7");	
			cha.setParameter("XAXIS_LABELS","125|250|500|1000|2000|4000|8000");
			cha.setParameter("YAXIS_FONT","Serif|BOLD|10");
			cha.setParameter("YAXIS_FONT_COLOR","0xffffff");
			cha.setParameter("XAXIS_FONT","Serif|BOLD|10");
			cha.setParameter("XAXIS_FONT_COLOR","0xffffff");
			cha.setParameter("YAXIS_TICKATBASE","true");
			cha.setParameter("XAXIS_TICKATBASE","false");
			cha.setParameter("BIG_TICK_INTERVALY","1");
			cha.setParameter("YAXIS_INTEGER","false");
			cha.setParameter("YAXIS_LABEL_FORMAT","#0.00");
			cha.setParameter("XAXIS_START_WITH_BIG_TICK","TRUE");
			cha.setParameter("YAXIS_START_WITH_BIG_TICK","FALSE");
			cha.setParameter("LEGEND_VERTICAL","FALSE");
			cha.setParameter("SERIE_TYPE_1","CURVE");
			cha.setParameter("SERIE_1","Products");
			cha.setParameter("SERIE_FONT_1","Serif|BOLD|10");
			cha.setParameter("SERIE_COLOR_1","WHITE");
			cha.setParameter("SERIE_STYLE_1","3|YELLOW|LINE");
			cha.setParameter("SERIE_POINT_1","true");
			cha.setParameter("LEGEND_POSITION","BOTTOM");
			cha.setParameter("LEGEND_MARGIN","0");
			cha.setParameter("LEFT_MARGIN","0.12");
			cha.setParameter("RIGHT_MARGIN","0.1");
			cha.setParameter("TOP_MARGIN","0.1");
			cha.setParameter("BOTTOM_MARGIN","0.2");
			cha.setParameter("LEGEND","FALSE");
			Log.i(ChartPanel.TAG,"Building chart ...");

			Chart c=cha.build(false,false);	
			c.setWidth(300);
			c.setHeight(300);

			
			Log.i(ChartPanel.TAG,"Build ok");			
			
			return c;


		}
	    
	    /**
		 * this method creates realtime data for the realtime example every 2 seconds
		 *
		 */
	   private void createRealtimedata(ChartLoader loader) {
			//	create chart

			//	set initial value of the X Axis based on the time
			java.util.Date now=java.util.Calendar.getInstance().getTime();
			java.text.SimpleDateFormat formatter = new java.text.SimpleDateFormat("dd/MM/yy hh:mm:ss");

			loader.setParameter("XAXIS_INITIAL_DATE",formatter.format(now));


			//	create random data based on the time
			java.util.Calendar cal=java.util.Calendar.getInstance();
			String data1="";
			String data2="";
			for (int i=0;i<9;i++) {		
				cal.add(java.util.Calendar.SECOND,-2);
				if (data1.length()>0) data1="|" + data1;
				data1=""+cal.get(java.util.Calendar.SECOND)+ data1;
				if (data2.length()>0) data2="|" + data2;
				data2=""+(cal.get(java.util.Calendar.SECOND)/6)+ data2;		
			}

			loader.setParameter("SERIE_DATA_1",data1);
			loader.setParameter("SERIE_DATA_2",data2);
			

	   }    
		
}